@@ -7,9 +7,11 @@ import json
 
 from .imports.qt import QtWidgets, QtCore, QtGui, pyqtSignal, pyqtSlot
 from .imports.openpose import OPENPOSE_LOADED
+
 if OPENPOSE_LOADED:
     from .imports.openpose import op
 from ..config import DATASETS_PATH
+from ..datasets.body_models import BODY25
 
 
 class ScrollLabel(QtWidgets.QScrollArea):
@@ -537,10 +539,8 @@ class CreateDatasetDialog(QtWidgets.QDialog):
             "data": [],
         }
         if self.handSelection.getCurrentFocusID() == 2 and OPENPOSE_LOADED:
-            info["info"]["BODY25_Mapping"] = op.getPoseBodyPartMapping(
-                op.PoseModel.BODY_25
-            )
-            info["info"]["BODY25_Pairs"] = op.getPosePartPairs(op.PoseModel.BODY_25)
+            info["info"]["BODY25_Mapping"] = BODY25.mapping
+            info["info"]["BODY25_Pairs"] = BODY25.pairs
         return info
 
     @pyqtSlot()
